function x=gbd_rnd2(beta,N,heap);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GBD_RND2 - generates observations from a distribution from 
% the Generalized Beta Distribution. 
% Statistics Toolbox is needed for this function.
%
% Input:
%   beta = the distribution parameters vector [beta(1) beta(2) beta(3) beta(4)]
%   N    = the size of the sample matrix (optional)
%   heap = the number of observations generated on one call of betarnd().  
%          default is 1000. heap is used to prevent the error message 'not enough memory'.
%
% Output:
%   x    = the random sample matrix  
%
% Copyright (c) Helsinki University of Technology,
% Signal Processing Laboratory,
% Jan Eriksson, Juha Karvanen, and Visa Koivunen.
%
% For details see the files readme.txt
% and gpl.txt provided within the same package.
%
% Last modified: 17.9.2002 JK
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin==0, disp('Usage: gbd_rnd2(beta,[N])');
              error('Not enough input arguments.');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If N is not given, the default matrix size 1x1 (a single value).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin==1, N=1; end
if nargin<3, heap=1000; end

if size(N(:),1)<2, N(2)=N(1); end;
for i=1:ceil(N(1)*N(2)/heap),
x((1+(i-1)*heap):(i*heap))=beta(1)+beta(2)*betarnd(beta(3)+1,beta(4)+1,1,heap);
end
x=reshape(x(1:(N(1)*N(2))),N);
% The end of the function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


